==> com.liferay.dynamic.data.mapping.form.builder-2.0.18-sources-commercial.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldEditedHandler.es.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import * as FormSupport from 'dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es';
import {updateFocusedField} from '../util/focusedField.es';
import {updateRulesFieldName} from '../util/rules.es';

export const updatePages = (pages, oldFieldProperties, newFieldProperties) => {
	const {fieldName} = oldFieldProperties;

	return FormSupport.updateField(pages, fieldName, newFieldProperties);
};

export const updateRules = (rules, oldFieldProperties, newFieldProperties) => {
	const {fieldName} = oldFieldProperties;
	const newFieldName = newFieldProperties.fieldName;

	return updateRulesFieldName(rules, fieldName, newFieldName);
};

export const updateField = (
	state,
	defaultLanguageId,
	editingLanguageId,
	fieldName,
	fieldValue
) => {
	const {focusedField, pages, rules} = state;
	const updatedFocusedField = updateFocusedField(
		state,
		defaultLanguageId,
		editingLanguageId,
		fieldName,
		fieldValue
	);

	return {
		focusedField: updatedFocusedField,
		pages: updatePages(pages, focusedField, updatedFocusedField),
		rules: updateRules(rules, focusedField, updatedFocusedField)
	};
};

export const handleFieldEdited = (
	state,
	defaultLanguageId,
	editingLanguageId,
	event
) => {
	const {propertyName, propertyValue} = event;
	let newState = {};

	if (propertyName !== 'name' || propertyValue !== '') {
		newState = updateField(
			state,
			defaultLanguageId,
			editingLanguageId,
			propertyName,
			propertyValue
		);
	}

	return newState;
};

export default handleFieldEdited;

==> com.liferay.dynamic.data.mapping.form.builder-2.0.31-sources-commercial.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldEditedHandler.es.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import * as FormSupport from 'dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es';
import {updateFocusedField} from '../util/focusedField.es';
import {updateRulesReferences} from '../util/rules.es';

export const updatePages = (pages, oldFieldProperties, newFieldProperties) => {
	const {fieldName} = oldFieldProperties;

	return FormSupport.updateField(pages, fieldName, newFieldProperties);
};

export const updateField = (
	state,
	defaultLanguageId,
	editingLanguageId,
	fieldName,
	fieldValue
) => {
	const {focusedField, pages, rules} = state;
	const updatedFocusedField = updateFocusedField(
		state,
		defaultLanguageId,
		editingLanguageId,
		fieldName,
		fieldValue
	);

	return {
		focusedField: updatedFocusedField,
		pages: updatePages(pages, focusedField, updatedFocusedField),
		rules: updateRulesReferences(rules, focusedField, updatedFocusedField)
	};
};

export const handleFieldEdited = (
	state,
	defaultLanguageId,
	editingLanguageId,
	event
) => {
	const {propertyName, propertyValue} = event;
	let newState = {};

	if (propertyName !== 'name' || propertyValue !== '') {
		newState = updateField(
			state,
			defaultLanguageId,
			editingLanguageId,
			propertyName,
			propertyValue
		);
	}

	return newState;
};

export default handleFieldEdited;
